@@ -1,14 +1,14 @@
 #include <QtGui>
 
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
-#include <mbarcode-qt/mainwindow.h>
+#include <mbarcode-qt/pluginaction.h>
+#include <mbarcode-qt/maemobarcodewindow.h>
 
 #include "wrplugin.h"
 #include "wrsink.h"
 #include "searchprovider.h"
 
-void WrPlugin::initInterface(MainWindow *parent) {
+void WrPlugin::initInterface(QWidget *parent) {
     settings = new QSettings("mbarcode", "webrequest-plugin", this);
     sink = new WrSink(this);
     sink->setPlugin(this);
@@ -23,8 +23,8 @@ void WrPlugin::initInterface(MainWindow *parent) {
     settings->endArray();
 }
 
-QSet<SinkPlugin*> WrPlugin::getSinkPlugins() {
-    QSet<SinkPlugin*> newList;
+QSet<PluginAction*> WrPlugin::getPluginActions() {
+    QSet<PluginAction*> newList;
     newList.insert(sink);
     return newList;
 }
@@ -58,6 +58,7 @@ void WrPlugin::setSearchProviders(QList<SearchProvider*> providers) {
 void WrPlugin::barcodeAnalysed(QString barcodeType, QString barcodeData) {
     qDebug() << "WrPlugin::barcodeAnalysed() recieved analysed signal" << barcodeData;
     barcodeText = barcodeData;
+    sink->barcodeText = barcodeData;
 }
 
 void WrPlugin::saveSearchProviders() {
