@@ -7,8 +7,8 @@
 
 #include <mbarcode-qt/plugininterfaces.h>
 
-class SinkPlugin;
-class MainWindow;
+class PluginAction;
+class MaemoBarcodeWindow;
 class WrSink;
 class SearchProvider;
 
@@ -17,8 +17,8 @@ class WrPlugin : public QObject, public PluginInterface
     Q_OBJECT
     Q_INTERFACES(PluginInterface)
 public:
-    void initInterface(MainWindow *parent);
-    QSet<SinkPlugin*> getSinkPlugins();
+    void initInterface(QWidget *parent);
+    QSet<PluginAction*> getPluginActions();
     QString getName() {return "Webrequest";}
     QSettings *settings;
     QList<SearchProvider*> searchProviders();
@@ -30,7 +30,7 @@ public:
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
 private:
-    MainWindow *parent;
+    QWidget *parent;
     QString url;
     WrSink *sink;
     QList<SearchProvider*> providers;
